@@ -192,6 +192,22 @@ PIRKeynameMgr::PIRKeynameMgr()
   keynameStrings[RobotSpot_Key] = "Robot Spot";
   keynameStrings[RobotMax_Key] = "Robot Max";
   keynameStrings[RobotClean_Key] = "Robot Clean";
+  keynameStrings[PSSelect_Key] = "Select";
+  keynameStrings[PSStart_Key] = "Start";
+  keynameStrings[PSL1_Key] = "Left 1";
+  keynameStrings[PSL2_Key] = "Left 2";
+  keynameStrings[PSL3_Key] = "Left 3";
+  keynameStrings[PSR1_Key] = "Right 1";
+  keynameStrings[PSR2_Key] = "Right 2";
+  keynameStrings[PSR3_Key] = "Right 3";
+  keynameStrings[PSUp_Key] = "Up";
+  keynameStrings[PSDown_Key] = "Down";
+  keynameStrings[PSLeft_Key] = "Left";
+  keynameStrings[PSRight_Key] = "Right";
+  keynameStrings[PSTriangle_Key] = "Triangle";
+  keynameStrings[PSCircle_Key] = "Circle";
+  keynameStrings[PSCross_Key] = "Cross";
+  keynameStrings[PSSquare_Key] = "Square";
   keynameStrings[OpenShutter_Key] = "Open Shutter";
   keynameStrings[DelayedOpenShutter_Key] = "Open Shutter After Delay";
   keynameStrings[Captions_Key] = "Captions / Subtitles";
