@@ -20,6 +20,7 @@ enum PIRPanelName
   Audio_Panel,
   Camera_Panel,
   Roomba_Panel,
+  Playstation_Panel,
   User_Panel,
   Macro_Panel,
 //  PowerSearch_Panel,
@@ -40,6 +41,7 @@ enum PIRTabBarName
   Record_Tabs,
   Camera_Tabs,
   Roomba_Tabs,
+  Console_Tabs,
   Macro_Tabs,
 //  PowerSearch_Tabs,
   Advanced_Tabs,
